<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'AIOSEO\\Plugin\\AIOSEO' => $baseDir . '/app/AIOSEO.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Admin' => $baseDir . '/app/Common/Admin/Admin.php',
    'AIOSEO\\Plugin\\Common\\Admin\\ConflictingPlugins' => $baseDir . '/app/Common/Admin/ConflictingPlugins.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Dashboard' => $baseDir . '/app/Common/Admin/Dashboard.php',
    'AIOSEO\\Plugin\\Common\\Admin\\DeactivationSurvey' => $baseDir . '/app/Common/Admin/DeactivationSurvey.php',
    'AIOSEO\\Plugin\\Common\\Admin\\NetworkAdmin' => $baseDir . '/app/Common/Admin/NetworkAdmin.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\ConflictingPlugins' => $baseDir . '/app/Common/Admin/Notices/ConflictingPlugins.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\DeprecatedWordPress' => $baseDir . '/app/Common/Admin/Notices/DeprecatedWordPress.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Import' => $baseDir . '/app/Common/Admin/Notices/Import.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Migration' => $baseDir . '/app/Common/Admin/Notices/Migration.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Notices' => $baseDir . '/app/Common/Admin/Notices/Notices.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\Review' => $baseDir . '/app/Common/Admin/Notices/Review.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Notices\\WpNotices' => $baseDir . '/app/Common/Admin/Notices/WpNotices.php',
    'AIOSEO\\Plugin\\Common\\Admin\\PostSettings' => $baseDir . '/app/Common/Admin/PostSettings.php',
    'AIOSEO\\Plugin\\Common\\Admin\\SeoAnalysis' => $baseDir . '/app/Common/Admin/SeoAnalysis.php',
    'AIOSEO\\Plugin\\Common\\Admin\\SiteHealth' => $baseDir . '/app/Common/Admin/SiteHealth.php',
    'AIOSEO\\Plugin\\Common\\Admin\\SlugMonitor' => $baseDir . '/app/Common/Admin/SlugMonitor.php',
    'AIOSEO\\Plugin\\Common\\Admin\\Usage' => $baseDir . '/app/Common/Admin/Usage.php',
    'AIOSEO\\Plugin\\Common\\Admin\\WritingAssistant' => $baseDir . '/app/Common/Admin/WritingAssistant.php',
    'AIOSEO\\Plugin\\Common\\Api\\Analyze' => $baseDir . '/app/Common/Api/Analyze.php',
    'AIOSEO\\Plugin\\Common\\Api\\Api' => $baseDir . '/app/Common/Api/Api.php',
    'AIOSEO\\Plugin\\Common\\Api\\Connect' => $baseDir . '/app/Common/Api/Connect.php',
    'AIOSEO\\Plugin\\Common\\Api\\EmailSummary' => $baseDir . '/app/Common/Api/EmailSummary.php',
    'AIOSEO\\Plugin\\Common\\Api\\Integrations\\Semrush' => $baseDir . '/app/Common/Api/Integrations/Semrush.php',
    'AIOSEO\\Plugin\\Common\\Api\\Integrations\\WpCode' => $baseDir . '/app/Common/Api/Integrations/WpCode.php',
    'AIOSEO\\Plugin\\Common\\Api\\Migration' => $baseDir . '/app/Common/Api/Migration.php',
    'AIOSEO\\Plugin\\Common\\Api\\Network' => $baseDir . '/app/Common/Api/Network.php',
    'AIOSEO\\Plugin\\Common\\Api\\Notifications' => $baseDir . '/app/Common/Api/Notifications.php',
    'AIOSEO\\Plugin\\Common\\Api\\Ping' => $baseDir . '/app/Common/Api/Ping.php',
    'AIOSEO\\Plugin\\Common\\Api\\Plugins' => $baseDir . '/app/Common/Api/Plugins.php',
    'AIOSEO\\Plugin\\Common\\Api\\PostsTerms' => $baseDir . '/app/Common/Api/PostsTerms.php',
    'AIOSEO\\Plugin\\Common\\Api\\SearchStatistics' => $baseDir . '/app/Common/Api/SearchStatistics.php',
    'AIOSEO\\Plugin\\Common\\Api\\Settings' => $baseDir . '/app/Common/Api/Settings.php',
    'AIOSEO\\Plugin\\Common\\Api\\Sitemaps' => $baseDir . '/app/Common/Api/Sitemaps.php',
    'AIOSEO\\Plugin\\Common\\Api\\Tags' => $baseDir . '/app/Common/Api/Tags.php',
    'AIOSEO\\Plugin\\Common\\Api\\Tools' => $baseDir . '/app/Common/Api/Tools.php',
    'AIOSEO\\Plugin\\Common\\Api\\User' => $baseDir . '/app/Common/Api/User.php',
    'AIOSEO\\Plugin\\Common\\Api\\Wizard' => $baseDir . '/app/Common/Api/Wizard.php',
    'AIOSEO\\Plugin\\Common\\Api\\WritingAssistant' => $baseDir . '/app/Common/Api/WritingAssistant.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Block' => $baseDir . '/app/Common/Breadcrumbs/Block.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Breadcrumbs' => $baseDir . '/app/Common/Breadcrumbs/Breadcrumbs.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Frontend' => $baseDir . '/app/Common/Breadcrumbs/Frontend.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Shortcode' => $baseDir . '/app/Common/Breadcrumbs/Shortcode.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Tags' => $baseDir . '/app/Common/Breadcrumbs/Tags.php',
    'AIOSEO\\Plugin\\Common\\Breadcrumbs\\Widget' => $baseDir . '/app/Common/Breadcrumbs/Widget.php',
    'AIOSEO\\Plugin\\Common\\Core\\Core' => $baseDir . '/app/Common/Core/Core.php',
    'AIOSEO\\Plugin\\Common\\EmailReports\\EmailReports' => $baseDir . '/app/Common/EmailReports/EmailReports.php',
    'AIOSEO\\Plugin\\Common\\EmailReports\\Mail' => $baseDir . '/app/Common/EmailReports/Mail.php',
    'AIOSEO\\Plugin\\Common\\EmailReports\\Summary\\Content' => $baseDir . '/app/Common/EmailReports/Summary/Content.php',
    'AIOSEO\\Plugin\\Common\\EmailReports\\Summary\\Summary' => $baseDir . '/app/Common/EmailReports/Summary/Summary.php',
    'AIOSEO\\Plugin\\Common\\Help\\Help' => $baseDir . '/app/Common/Help/Help.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\Helpers' => $baseDir . '/app/Common/ImportExport/Helpers.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\ImportExport' => $baseDir . '/app/Common/ImportExport/ImportExport.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\Importer' => $baseDir . '/app/Common/ImportExport/Importer.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\GeneralSettings' => $baseDir . '/app/Common/ImportExport/RankMath/GeneralSettings.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\Helpers' => $baseDir . '/app/Common/ImportExport/RankMath/Helpers.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\PostMeta' => $baseDir . '/app/Common/ImportExport/RankMath/PostMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\RankMath' => $baseDir . '/app/Common/ImportExport/RankMath/RankMath.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\Sitemap' => $baseDir . '/app/Common/ImportExport/RankMath/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\RankMath\\TitleMeta' => $baseDir . '/app/Common/ImportExport/RankMath/TitleMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SearchAppearance' => $baseDir . '/app/Common/ImportExport/SearchAppearance.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Analytics' => $baseDir . '/app/Common/ImportExport/SeoPress/Analytics.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Breadcrumbs' => $baseDir . '/app/Common/ImportExport/SeoPress/Breadcrumbs.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\GeneralSettings' => $baseDir . '/app/Common/ImportExport/SeoPress/GeneralSettings.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Helpers' => $baseDir . '/app/Common/ImportExport/SeoPress/Helpers.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\PostMeta' => $baseDir . '/app/Common/ImportExport/SeoPress/PostMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\RobotsTxt' => $baseDir . '/app/Common/ImportExport/SeoPress/RobotsTxt.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Rss' => $baseDir . '/app/Common/ImportExport/SeoPress/Rss.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\SeoPress' => $baseDir . '/app/Common/ImportExport/SeoPress/SeoPress.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Sitemap' => $baseDir . '/app/Common/ImportExport/SeoPress/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\SocialMeta' => $baseDir . '/app/Common/ImportExport/SeoPress/SocialMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\SeoPress\\Titles' => $baseDir . '/app/Common/ImportExport/SeoPress/Titles.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\GeneralSettings' => $baseDir . '/app/Common/ImportExport/YoastSeo/GeneralSettings.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\Helpers' => $baseDir . '/app/Common/ImportExport/YoastSeo/Helpers.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\PostMeta' => $baseDir . '/app/Common/ImportExport/YoastSeo/PostMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\SearchAppearance' => $baseDir . '/app/Common/ImportExport/YoastSeo/SearchAppearance.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\SocialMeta' => $baseDir . '/app/Common/ImportExport/YoastSeo/SocialMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\UserMeta' => $baseDir . '/app/Common/ImportExport/YoastSeo/UserMeta.php',
    'AIOSEO\\Plugin\\Common\\ImportExport\\YoastSeo\\YoastSeo' => $baseDir . '/app/Common/ImportExport/YoastSeo/YoastSeo.php',
    'AIOSEO\\Plugin\\Common\\Integrations\\BuddyPress' => $baseDir . '/app/Common/Integrations/BuddyPress.php',
    'AIOSEO\\Plugin\\Common\\Integrations\\Semrush' => $baseDir . '/app/Common/Integrations/Semrush.php',
    'AIOSEO\\Plugin\\Common\\Integrations\\WpCode' => $baseDir . '/app/Common/Integrations/WpCode.php',
    'AIOSEO\\Plugin\\Common\\Main\\Activate' => $baseDir . '/app/Common/Main/Activate.php',
    'AIOSEO\\Plugin\\Common\\Main\\CategoryBase' => $baseDir . '/app/Common/Main/CategoryBase.php',
    'AIOSEO\\Plugin\\Common\\Main\\Filters' => $baseDir . '/app/Common/Main/Filters.php',
    'AIOSEO\\Plugin\\Common\\Main\\Head' => $baseDir . '/app/Common/Main/Head.php',
    'AIOSEO\\Plugin\\Common\\Main\\Main' => $baseDir . '/app/Common/Main/Main.php',
    'AIOSEO\\Plugin\\Common\\Main\\Media' => $baseDir . '/app/Common/Main/Media.php',
    'AIOSEO\\Plugin\\Common\\Main\\PreUpdates' => $baseDir . '/app/Common/Main/PreUpdates.php',
    'AIOSEO\\Plugin\\Common\\Main\\QueryArgs' => $baseDir . '/app/Common/Main/QueryArgs.php',
    'AIOSEO\\Plugin\\Common\\Main\\Title' => $baseDir . '/app/Common/Main/Title.php',
    'AIOSEO\\Plugin\\Common\\Main\\Updates' => $baseDir . '/app/Common/Main/Updates.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Amp' => $baseDir . '/app/Common/Meta/Amp.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Description' => $baseDir . '/app/Common/Meta/Description.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Helpers' => $baseDir . '/app/Common/Meta/Helpers.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Included' => $baseDir . '/app/Common/Meta/Included.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Keywords' => $baseDir . '/app/Common/Meta/Keywords.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Links' => $baseDir . '/app/Common/Meta/Links.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Meta' => $baseDir . '/app/Common/Meta/Meta.php',
    'AIOSEO\\Plugin\\Common\\Meta\\MetaData' => $baseDir . '/app/Common/Meta/MetaData.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Robots' => $baseDir . '/app/Common/Meta/Robots.php',
    'AIOSEO\\Plugin\\Common\\Meta\\SiteVerification' => $baseDir . '/app/Common/Meta/SiteVerification.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Title' => $baseDir . '/app/Common/Meta/Title.php',
    'AIOSEO\\Plugin\\Common\\Meta\\Traits\\Helpers\\BuddyPress' => $baseDir . '/app/Common/Meta/Traits/Helpers/BuddyPress.php',
    'AIOSEO\\Plugin\\Common\\Migration\\BadRobots' => $baseDir . '/app/Common/Migration/BadRobots.php',
    'AIOSEO\\Plugin\\Common\\Migration\\GeneralSettings' => $baseDir . '/app/Common/Migration/GeneralSettings.php',
    'AIOSEO\\Plugin\\Common\\Migration\\Helpers' => $baseDir . '/app/Common/Migration/Helpers.php',
    'AIOSEO\\Plugin\\Common\\Migration\\Meta' => $baseDir . '/app/Common/Migration/Meta.php',
    'AIOSEO\\Plugin\\Common\\Migration\\Migration' => $baseDir . '/app/Common/Migration/Migration.php',
    'AIOSEO\\Plugin\\Common\\Migration\\OldOptions' => $baseDir . '/app/Common/Migration/OldOptions.php',
    'AIOSEO\\Plugin\\Common\\Migration\\RobotsTxt' => $baseDir . '/app/Common/Migration/RobotsTxt.php',
    'AIOSEO\\Plugin\\Common\\Migration\\Sitemap' => $baseDir . '/app/Common/Migration/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\Migration\\SocialMeta' => $baseDir . '/app/Common/Migration/SocialMeta.php',
    'AIOSEO\\Plugin\\Common\\Migration\\Wpml' => $baseDir . '/app/Common/Migration/Wpml.php',
    'AIOSEO\\Plugin\\Common\\Models\\CrawlCleanupBlockedArg' => $baseDir . '/app/Common/Models/CrawlCleanupBlockedArg.php',
    'AIOSEO\\Plugin\\Common\\Models\\CrawlCleanupLog' => $baseDir . '/app/Common/Models/CrawlCleanupLog.php',
    'AIOSEO\\Plugin\\Common\\Models\\Model' => $baseDir . '/app/Common/Models/Model.php',
    'AIOSEO\\Plugin\\Common\\Models\\Notification' => $baseDir . '/app/Common/Models/Notification.php',
    'AIOSEO\\Plugin\\Common\\Models\\Post' => $baseDir . '/app/Common/Models/Post.php',
    'AIOSEO\\Plugin\\Common\\Models\\WritingAssistantKeyword' => $baseDir . '/app/Common/Models/WritingAssistantKeyword.php',
    'AIOSEO\\Plugin\\Common\\Models\\WritingAssistantPost' => $baseDir . '/app/Common/Models/WritingAssistantPost.php',
    'AIOSEO\\Plugin\\Common\\Options\\Cache' => $baseDir . '/app/Common/Options/Cache.php',
    'AIOSEO\\Plugin\\Common\\Options\\DynamicBackup' => $baseDir . '/app/Common/Options/DynamicBackup.php',
    'AIOSEO\\Plugin\\Common\\Options\\DynamicOptions' => $baseDir . '/app/Common/Options/DynamicOptions.php',
    'AIOSEO\\Plugin\\Common\\Options\\InternalNetworkOptions' => $baseDir . '/app/Common/Options/InternalNetworkOptions.php',
    'AIOSEO\\Plugin\\Common\\Options\\InternalOptions' => $baseDir . '/app/Common/Options/InternalOptions.php',
    'AIOSEO\\Plugin\\Common\\Options\\NetworkOptions' => $baseDir . '/app/Common/Options/NetworkOptions.php',
    'AIOSEO\\Plugin\\Common\\Options\\Options' => $baseDir . '/app/Common/Options/Options.php',
    'AIOSEO\\Plugin\\Common\\QueryArgs\\CrawlCleanup' => $baseDir . '/app/Common/QueryArgs/CrawlCleanup.php',
    'AIOSEO\\Plugin\\Common\\Rss' => $baseDir . '/app/Common/Rss.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Breadcrumb' => $baseDir . '/app/Common/Schema/Breadcrumb.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Context' => $baseDir . '/app/Common/Schema/Context.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\AmpStory' => $baseDir . '/app/Common/Schema/Graphs/AmpStory.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\Article' => $baseDir . '/app/Common/Schema/Graphs/Article/Article.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\BlogPosting' => $baseDir . '/app/Common/Schema/Graphs/Article/BlogPosting.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Article\\NewsArticle' => $baseDir . '/app/Common/Schema/Graphs/Article/NewsArticle.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\BreadcrumbList' => $baseDir . '/app/Common/Schema/Graphs/BreadcrumbList.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Graph' => $baseDir . '/app/Common/Schema/Graphs/Graph.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\KnowledgeGraph\\KgOrganization' => $baseDir . '/app/Common/Schema/Graphs/KnowledgeGraph/KgOrganization.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\KnowledgeGraph\\KgPerson' => $baseDir . '/app/Common/Schema/Graphs/KnowledgeGraph/KgPerson.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\Traits\\Image' => $baseDir . '/app/Common/Schema/Graphs/Traits/Image.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\AboutPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/AboutPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\CheckoutPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/CheckoutPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\CollectionPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/CollectionPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ContactPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/ContactPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\FAQPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/FAQPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ItemPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/ItemPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\MedicalWebPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/MedicalWebPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\PersonAuthor' => $baseDir . '/app/Common/Schema/Graphs/WebPage/PersonAuthor.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\ProfilePage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/ProfilePage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\RealEstateListing' => $baseDir . '/app/Common/Schema/Graphs/WebPage/RealEstateListing.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\SearchResultsPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/SearchResultsPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebPage\\WebPage' => $baseDir . '/app/Common/Schema/Graphs/WebPage/WebPage.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Graphs\\WebSite' => $baseDir . '/app/Common/Schema/Graphs/WebSite.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Helpers' => $baseDir . '/app/Common/Schema/Helpers.php',
    'AIOSEO\\Plugin\\Common\\Schema\\Schema' => $baseDir . '/app/Common/Schema/Schema.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Api' => $baseDir . '/app/Common/SearchStatistics/Api/Api.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Auth' => $baseDir . '/app/Common/SearchStatistics/Api/Auth.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Listener' => $baseDir . '/app/Common/SearchStatistics/Api/Listener.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\Request' => $baseDir . '/app/Common/SearchStatistics/Api/Request.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Api\\TrustToken' => $baseDir . '/app/Common/SearchStatistics/Api/TrustToken.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\KeywordRankTracker' => $baseDir . '/app/Common/SearchStatistics/KeywordRankTracker.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Notices' => $baseDir . '/app/Common/SearchStatistics/Notices.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\SearchStatistics' => $baseDir . '/app/Common/SearchStatistics/SearchStatistics.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Site' => $baseDir . '/app/Common/SearchStatistics/Site.php',
    'AIOSEO\\Plugin\\Common\\SearchStatistics\\Sitemap' => $baseDir . '/app/Common/SearchStatistics/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\SeoRevisions\\SeoRevisions' => $baseDir . '/app/Common/SeoRevisions/SeoRevisions.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Content' => $baseDir . '/app/Common/Sitemap/Content.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\File' => $baseDir . '/app/Common/Sitemap/File.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Helpers' => $baseDir . '/app/Common/Sitemap/Helpers.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Block' => $baseDir . '/app/Common/Sitemap/Html/Block.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\CompactArchive' => $baseDir . '/app/Common/Sitemap/Html/CompactArchive.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Frontend' => $baseDir . '/app/Common/Sitemap/Html/Frontend.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Query' => $baseDir . '/app/Common/Sitemap/Html/Query.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Shortcode' => $baseDir . '/app/Common/Sitemap/Html/Shortcode.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Sitemap' => $baseDir . '/app/Common/Sitemap/Html/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Html\\Widget' => $baseDir . '/app/Common/Sitemap/Html/Widget.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Image\\Image' => $baseDir . '/app/Common/Sitemap/Image/Image.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Image\\ThirdParty' => $baseDir . '/app/Common/Sitemap/Image/ThirdParty.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Localization' => $baseDir . '/app/Common/Sitemap/Localization.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Output' => $baseDir . '/app/Common/Sitemap/Output.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Priority' => $baseDir . '/app/Common/Sitemap/Priority.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Query' => $baseDir . '/app/Common/Sitemap/Query.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\RequestParser' => $baseDir . '/app/Common/Sitemap/RequestParser.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Root' => $baseDir . '/app/Common/Sitemap/Root.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Sitemap' => $baseDir . '/app/Common/Sitemap/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\SitemapAbstract' => $baseDir . '/app/Common/Sitemap/SitemapAbstract.php',
    'AIOSEO\\Plugin\\Common\\Sitemap\\Xsl' => $baseDir . '/app/Common/Sitemap/Xsl.php',
    'AIOSEO\\Plugin\\Common\\Social\\Facebook' => $baseDir . '/app/Common/Social/Facebook.php',
    'AIOSEO\\Plugin\\Common\\Social\\Image' => $baseDir . '/app/Common/Social/Image.php',
    'AIOSEO\\Plugin\\Common\\Social\\Output' => $baseDir . '/app/Common/Social/Output.php',
    'AIOSEO\\Plugin\\Common\\Social\\Social' => $baseDir . '/app/Common/Social/Social.php',
    'AIOSEO\\Plugin\\Common\\Social\\Twitter' => $baseDir . '/app/Common/Social/Twitter.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\AdminBarNoindexWarning' => $baseDir . '/app/Common/Standalone/AdminBarNoindexWarning.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\Blocks' => $baseDir . '/app/Common/Standalone/Blocks/Blocks.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\FaqPage' => $baseDir . '/app/Common/Standalone/Blocks/FaqPage.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\Blocks\\TableOfContents' => $baseDir . '/app/Common/Standalone/Blocks/TableOfContents.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\BuddyPress' => $baseDir . '/app/Common/Standalone/BuddyPress/BuddyPress.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Component' => $baseDir . '/app/Common/Standalone/BuddyPress/Component.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Sitemap' => $baseDir . '/app/Common/Standalone/BuddyPress/Sitemap.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\BuddyPress\\Tags' => $baseDir . '/app/Common/Standalone/BuddyPress/Tags.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\DetailsColumn' => $baseDir . '/app/Common/Standalone/DetailsColumn.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\FlyoutMenu' => $baseDir . '/app/Common/Standalone/FlyoutMenu.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\HeadlineAnalyzer' => $baseDir . '/app/Common/Standalone/HeadlineAnalyzer.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\LimitModifiedDate' => $baseDir . '/app/Common/Standalone/LimitModifiedDate.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\Notifications' => $baseDir . '/app/Common/Standalone/Notifications.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Avada' => $baseDir . '/app/Common/Standalone/PageBuilders/Avada.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Base' => $baseDir . '/app/Common/Standalone/PageBuilders/Base.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Divi' => $baseDir . '/app/Common/Standalone/PageBuilders/Divi.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\Elementor' => $baseDir . '/app/Common/Standalone/PageBuilders/Elementor.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\SeedProd' => $baseDir . '/app/Common/Standalone/PageBuilders/SeedProd.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\SiteOrigin' => $baseDir . '/app/Common/Standalone/PageBuilders/SiteOrigin.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\ThriveArchitect' => $baseDir . '/app/Common/Standalone/PageBuilders/ThriveArchitect.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PageBuilders\\WPBakery' => $baseDir . '/app/Common/Standalone/PageBuilders/WPBakery.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PrimaryTerm' => $baseDir . '/app/Common/Standalone/PrimaryTerm.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\PublishPanel' => $baseDir . '/app/Common/Standalone/PublishPanel.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\SeoPreview' => $baseDir . '/app/Common/Standalone/SeoPreview.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\SetupWizard' => $baseDir . '/app/Common/Standalone/SetupWizard.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\Standalone' => $baseDir . '/app/Common/Standalone/Standalone.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\UserProfileTab' => $baseDir . '/app/Common/Standalone/UserProfileTab.php',
    'AIOSEO\\Plugin\\Common\\Standalone\\WpCode' => $baseDir . '/app/Common/Standalone/WpCode.php',
    'AIOSEO\\Plugin\\Common\\ThirdParty\\ThirdParty' => $baseDir . '/app/Common/ThirdParty/ThirdParty.php',
    'AIOSEO\\Plugin\\Common\\ThirdParty\\WebStories' => $baseDir . '/app/Common/ThirdParty/WebStories.php',
    'AIOSEO\\Plugin\\Common\\Tools\\BadBotBlocker' => $baseDir . '/app/Common/Tools/BadBotBlocker.php',
    'AIOSEO\\Plugin\\Common\\Tools\\Htaccess' => $baseDir . '/app/Common/Tools/Htaccess.php',
    'AIOSEO\\Plugin\\Common\\Tools\\RobotsTxt' => $baseDir . '/app/Common/Tools/RobotsTxt.php',
    'AIOSEO\\Plugin\\Common\\Tools\\SystemStatus' => $baseDir . '/app/Common/Tools/SystemStatus.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Assets' => $baseDir . '/app/Common/Traits/Assets.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Api' => $baseDir . '/app/Common/Traits/Helpers/Api.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Arrays' => $baseDir . '/app/Common/Traits/Helpers/Arrays.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Constants' => $baseDir . '/app/Common/Traits/Helpers/Constants.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\DateTime' => $baseDir . '/app/Common/Traits/Helpers/DateTime.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Deprecated' => $baseDir . '/app/Common/Traits/Helpers/Deprecated.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Language' => $baseDir . '/app/Common/Traits/Helpers/Language.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Numbers' => $baseDir . '/app/Common/Traits/Helpers/Numbers.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\PostType' => $baseDir . '/app/Common/Traits/Helpers/PostType.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Request' => $baseDir . '/app/Common/Traits/Helpers/Request.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Shortcodes' => $baseDir . '/app/Common/Traits/Helpers/Shortcodes.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Strings' => $baseDir . '/app/Common/Traits/Helpers/Strings.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Svg' => $baseDir . '/app/Common/Traits/Helpers/Svg.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\ThirdParty' => $baseDir . '/app/Common/Traits/Helpers/ThirdParty.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Url' => $baseDir . '/app/Common/Traits/Helpers/Url.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Vue' => $baseDir . '/app/Common/Traits/Helpers/Vue.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\Wp' => $baseDir . '/app/Common/Traits/Helpers/Wp.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpContext' => $baseDir . '/app/Common/Traits/Helpers/WpContext.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpMultisite' => $baseDir . '/app/Common/Traits/Helpers/WpMultisite.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Helpers\\WpUri' => $baseDir . '/app/Common/Traits/Helpers/WpUri.php',
    'AIOSEO\\Plugin\\Common\\Traits\\NetworkOptions' => $baseDir . '/app/Common/Traits/NetworkOptions.php',
    'AIOSEO\\Plugin\\Common\\Traits\\Options' => $baseDir . '/app/Common/Traits/Options.php',
    'AIOSEO\\Plugin\\Common\\Traits\\SocialProfiles' => $baseDir . '/app/Common/Traits/SocialProfiles.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Access' => $baseDir . '/app/Common/Utils/Access.php',
    'AIOSEO\\Plugin\\Common\\Utils\\ActionScheduler' => $baseDir . '/app/Common/Utils/ActionScheduler.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Addons' => $baseDir . '/app/Common/Utils/Addons.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Assets' => $baseDir . '/app/Common/Utils/Assets.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Backup' => $baseDir . '/app/Common/Utils/Backup.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Blocks' => $baseDir . '/app/Common/Utils/Blocks.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Cache' => $baseDir . '/app/Common/Utils/Cache.php',
    'AIOSEO\\Plugin\\Common\\Utils\\CachePrune' => $baseDir . '/app/Common/Utils/CachePrune.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Database' => $baseDir . '/app/Common/Utils/Database.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Features' => $baseDir . '/app/Common/Utils/Features.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Filesystem' => $baseDir . '/app/Common/Utils/Filesystem.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Helpers' => $baseDir . '/app/Common/Utils/Helpers.php',
    'AIOSEO\\Plugin\\Common\\Utils\\NetworkCache' => $baseDir . '/app/Common/Utils/NetworkCache.php',
    'AIOSEO\\Plugin\\Common\\Utils\\PluginUpgraderSilentAjax' => $baseDir . '/app/Common/Utils/PluginUpgraderSilentAjax.php',
    'AIOSEO\\Plugin\\Common\\Utils\\PluginUpgraderSkin' => $baseDir . '/app/Common/Utils/PluginUpgraderSkin.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Tags' => $baseDir . '/app/Common/Utils/Tags.php',
    'AIOSEO\\Plugin\\Common\\Utils\\Templates' => $baseDir . '/app/Common/Utils/Templates.php',
    'AIOSEO\\Plugin\\Common\\Utils\\VueSettings' => $baseDir . '/app/Common/Utils/VueSettings.php',
    'AIOSEO\\Plugin\\Common\\WritingAssistant\\SeoBoost\\SeoBoost' => $baseDir . '/app/Common/WritingAssistant/SeoBoost/SeoBoost.php',
    'AIOSEO\\Plugin\\Common\\WritingAssistant\\SeoBoost\\Service' => $baseDir . '/app/Common/WritingAssistant/SeoBoost/Service.php',
    'AIOSEO\\Plugin\\Common\\WritingAssistant\\Utils\\Helpers' => $baseDir . '/app/Common/WritingAssistant/Utils/Helpers.php',
    'AIOSEO\\Plugin\\Common\\WritingAssistant\\WritingAssistant' => $baseDir . '/app/Common/WritingAssistant/WritingAssistant.php',
    'AIOSEO\\Plugin\\Lite\\Admin\\Admin' => $baseDir . '/app/Lite/Admin/Admin.php',
    'AIOSEO\\Plugin\\Lite\\Admin\\Connect' => $baseDir . '/app/Lite/Admin/Connect.php',
    'AIOSEO\\Plugin\\Lite\\Admin\\Notices\\Notices' => $baseDir . '/app/Lite/Admin/Notices/Notices.php',
    'AIOSEO\\Plugin\\Lite\\Admin\\PostSettings' => $baseDir . '/app/Lite/Admin/PostSettings.php',
    'AIOSEO\\Plugin\\Lite\\Admin\\Usage' => $baseDir . '/app/Lite/Admin/Usage.php',
    'AIOSEO\\Plugin\\Lite\\Api\\Api' => $baseDir . '/app/Lite/Api/Api.php',
    'AIOSEO\\Plugin\\Lite\\Api\\Wizard' => $baseDir . '/app/Lite/Api/Wizard.php',
    'AIOSEO\\Plugin\\Lite\\Main\\Filters' => $baseDir . '/app/Lite/Main/Filters.php',
    'AIOSEO\\Plugin\\Lite\\Options\\InternalOptions' => $baseDir . '/app/Lite/Options/InternalOptions.php',
    'AIOSEO\\Plugin\\Lite\\Options\\Options' => $baseDir . '/app/Lite/Options/Options.php',
    'AIOSEO\\Plugin\\Lite\\Traits\\Options' => $baseDir . '/app/Lite/Traits/Options.php',
    'AIOSEO\\Plugin\\Lite\\Utils\\Helpers' => $baseDir . '/app/Lite/Utils/Helpers.php',
    'AIOSEO\\Vendor\\Monolog\\ErrorHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/ErrorHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\ChromePHPFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ChromePHPFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\ElasticaFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ElasticaFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\FlowdockFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FlowdockFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\FluentdFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FluentdFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\FormatterInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/FormatterInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\GelfMessageFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/GelfMessageFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\HtmlFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/HtmlFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\JsonFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/JsonFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\LineFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LineFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\LogglyFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LogglyFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\LogstashFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/LogstashFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\MongoDBFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/MongoDBFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\NormalizerFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/NormalizerFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\ScalarFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/ScalarFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Formatter\\WildfireFormatter' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Formatter/WildfireFormatter.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\AbstractHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\AbstractProcessingHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractProcessingHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\AbstractSyslogHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AbstractSyslogHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\AmqpHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/AmqpHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\BrowserConsoleHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/BrowserConsoleHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\BufferHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/BufferHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ChromePHPHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ChromePHPHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\CouchDBHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/CouchDBHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\CubeHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/CubeHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\Curl\\Util' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/Curl/Util.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\DeduplicationHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DeduplicationHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\DoctrineCouchDBHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DoctrineCouchDBHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\DynamoDbHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/DynamoDbHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ElasticSearchHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ElasticSearchHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ErrorLogHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ErrorLogHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FilterHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FilterHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FingersCrossedHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossedHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FingersCrossed\\ActivationStrategyInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ActivationStrategyInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FingersCrossed\\ChannelLevelActivationStrategy' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ChannelLevelActivationStrategy.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FingersCrossed\\ErrorLevelActivationStrategy' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FingersCrossed/ErrorLevelActivationStrategy.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FirePHPHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FirePHPHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FleepHookHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FleepHookHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FlowdockHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FlowdockHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FormattableHandlerInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FormattableHandlerInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\FormattableHandlerTrait' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/FormattableHandlerTrait.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\GelfHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/GelfHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\GroupHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/GroupHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\HandlerInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HandlerInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\HandlerWrapper' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HandlerWrapper.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\HipChatHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/HipChatHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\IFTTTHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/IFTTTHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\InsightOpsHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/InsightOpsHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\LogEntriesHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/LogEntriesHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\LogglyHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/LogglyHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\MailHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MailHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\MandrillHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MandrillHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\MissingExtensionException' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MissingExtensionException.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\MongoDBHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/MongoDBHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\NativeMailerHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NativeMailerHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\NewRelicHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NewRelicHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\NullHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/NullHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\PHPConsoleHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PHPConsoleHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ProcessableHandlerInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ProcessableHandlerInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ProcessableHandlerTrait' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ProcessableHandlerTrait.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\PsrHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PsrHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\PushoverHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/PushoverHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\RavenHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RavenHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\RedisHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RedisHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\RollbarHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RollbarHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\RotatingFileHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/RotatingFileHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SamplingHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SamplingHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SlackHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SlackWebhookHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackWebhookHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\Slack\\SlackRecord' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/Slack/SlackRecord.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SlackbotHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SlackbotHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SocketHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SocketHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\StreamHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/StreamHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SwiftMailerHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SwiftMailerHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SyslogHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SyslogUdpHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogUdpHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\SyslogUdp\\UdpSocket' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/SyslogUdp/UdpSocket.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\TestHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/TestHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\WhatFailureGroupHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/WhatFailureGroupHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Handler\\ZendMonitorHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Handler/ZendMonitorHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Logger' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Logger.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\GitProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/GitProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\IntrospectionProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/IntrospectionProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\MemoryPeakUsageProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryPeakUsageProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\MemoryProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\MemoryUsageProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MemoryUsageProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\MercurialProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/MercurialProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\ProcessIdProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/ProcessIdProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\ProcessorInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/ProcessorInterface.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\PsrLogMessageProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/PsrLogMessageProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\TagProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/TagProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\UidProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/UidProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Processor\\WebProcessor' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Processor/WebProcessor.php',
    'AIOSEO\\Vendor\\Monolog\\Registry' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Registry.php',
    'AIOSEO\\Vendor\\Monolog\\ResettableInterface' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/ResettableInterface.php',
    'AIOSEO\\Vendor\\Monolog\\SignalHandler' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/SignalHandler.php',
    'AIOSEO\\Vendor\\Monolog\\Utils' => $baseDir . '/vendor_prefixed/monolog/monolog/src/Monolog/Utils.php',
    'AIOSEO\\Vendor\\Psr\\Log\\AbstractLogger' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/AbstractLogger.php',
    'AIOSEO\\Vendor\\Psr\\Log\\InvalidArgumentException' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/InvalidArgumentException.php',
    'AIOSEO\\Vendor\\Psr\\Log\\LogLevel' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/LogLevel.php',
    'AIOSEO\\Vendor\\Psr\\Log\\LoggerAwareInterface' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareInterface.php',
    'AIOSEO\\Vendor\\Psr\\Log\\LoggerAwareTrait' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/LoggerAwareTrait.php',
    'AIOSEO\\Vendor\\Psr\\Log\\LoggerInterface' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/LoggerInterface.php',
    'AIOSEO\\Vendor\\Psr\\Log\\LoggerTrait' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/LoggerTrait.php',
    'AIOSEO\\Vendor\\Psr\\Log\\NullLogger' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/NullLogger.php',
    'AIOSEO\\Vendor\\Psr\\Log\\Test\\DummyTest' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/Test/DummyTest.php',
    'AIOSEO\\Vendor\\Psr\\Log\\Test\\LoggerInterfaceTest' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/Test/LoggerInterfaceTest.php',
    'AIOSEO\\Vendor\\Psr\\Log\\Test\\TestLogger' => $baseDir . '/vendor_prefixed/psr/log/Psr/Log/Test/TestLogger.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'PHPInsight\\Autoloader' => $vendorDir . '/jwhennessey/phpinsight/lib/PHPInsight/Autoloader.php',
    'PHPInsight\\Sentiment' => $vendorDir . '/jwhennessey/phpinsight/lib/PHPInsight/Sentiment.php',
);
