<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Admin\\Admin' => $baseDir . '/app/Admin/Admin.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Admin\\Location' => $baseDir . '/app/Admin/Location.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Admin\\LocationCategory' => $baseDir . '/app/Admin/LocationCategory.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Admin\\Usage' => $baseDir . '/app/Admin/Usage.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Api\\Api' => $baseDir . '/app/Api/Api.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Api\\Import' => $baseDir . '/app/Api/Import.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Api\\Maps' => $baseDir . '/app/Api/Maps.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\Blocks' => $baseDir . '/app/Blocks/Blocks.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\BusinessInfo' => $baseDir . '/app/Blocks/BusinessInfo.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\LocationCategories' => $baseDir . '/app/Blocks/LocationCategories.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\Locations' => $baseDir . '/app/Blocks/Locations.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\Map' => $baseDir . '/app/Blocks/Map.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Blocks\\OpeningHours' => $baseDir . '/app/Blocks/OpeningHours.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Helpers' => $baseDir . '/app/Import/Helpers.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Import' => $baseDir . '/app/Import/Import.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Importer' => $baseDir . '/app/Import/Importer.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Notifications' => $baseDir . '/app/Import/Notifications.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Plugins\\RankMath' => $baseDir . '/app/Import/Plugins/RankMath.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Plugins\\SeoPress' => $baseDir . '/app/Import/Plugins/SeoPress.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Import\\Plugins\\YoastSeo' => $baseDir . '/app/Import/Plugins/YoastSeo.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\LocalBusiness' => $baseDir . '/app/LocalBusiness.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Locations\\Locations' => $baseDir . '/app/Locations/Locations.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Locations\\Maps' => $baseDir . '/app/Locations/Maps.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Main\\Activate' => $baseDir . '/app/Main/Activate.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Main\\Search' => $baseDir . '/app/Main/Search.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Main\\Updates' => $baseDir . '/app/Main/Updates.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Models\\Post' => $baseDir . '/app/Models/Post.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Schema\\Graphs\\Base' => $baseDir . '/app/Schema/Graphs/Base.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Schema\\Graphs\\KgOrganization' => $baseDir . '/app/Schema/Graphs/KgOrganization.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Schema\\Graphs\\LocalBusiness' => $baseDir . '/app/Schema/Graphs/LocalBusiness.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Schema\\Schema' => $baseDir . '/app/Schema/Schema.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Shortcodes\\Shortcodes' => $baseDir . '/app/Shortcodes/Shortcodes.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Access' => $baseDir . '/app/Utils/Access.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Assets' => $baseDir . '/app/Utils/Assets.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Cache' => $baseDir . '/app/Utils/Cache.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Helpers' => $baseDir . '/app/Utils/Helpers.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\InternalOptions' => $baseDir . '/app/Utils/InternalOptions.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Tags' => $baseDir . '/app/Utils/Tags.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Utils\\Templates' => $baseDir . '/app/Utils/Templates.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Widgets\\BusinessInfo' => $baseDir . '/app/Widgets/BusinessInfo.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Widgets\\Locations' => $baseDir . '/app/Widgets/Locations.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Widgets\\Map' => $baseDir . '/app/Widgets/Map.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Widgets\\OpeningHours' => $baseDir . '/app/Widgets/OpeningHours.php',
    'AIOSEO\\Plugin\\Addon\\LocalBusiness\\Widgets\\Widgets' => $baseDir . '/app/Widgets/Widgets.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
);
