<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'WPSEO_CLI_Premium_Requirement' => $baseDir . '/cli/cli-premium-requirement.php',
    'WPSEO_CLI_Redirect_Base_Command' => $baseDir . '/cli/cli-redirect-base-command.php',
    'WPSEO_CLI_Redirect_Command_Namespace' => $baseDir . '/cli/cli-redirect-command-namespace.php',
    'WPSEO_CLI_Redirect_Create_Command' => $baseDir . '/cli/cli-redirect-create-command.php',
    'WPSEO_CLI_Redirect_Delete_Command' => $baseDir . '/cli/cli-redirect-delete-command.php',
    'WPSEO_CLI_Redirect_Follow_Command' => $baseDir . '/cli/cli-redirect-follow-command.php',
    'WPSEO_CLI_Redirect_Has_Command' => $baseDir . '/cli/cli-redirect-has-command.php',
    'WPSEO_CLI_Redirect_List_Command' => $baseDir . '/cli/cli-redirect-list-command.php',
    'WPSEO_CLI_Redirect_Update_Command' => $baseDir . '/cli/cli-redirect-update-command.php',
    'WPSEO_Custom_Fields_Plugin' => $baseDir . '/classes/custom-fields-plugin.php',
    'WPSEO_Executable_Redirect' => $baseDir . '/classes/redirect/executable-redirect.php',
    'WPSEO_Export_Keywords_CSV' => $baseDir . '/classes/export/export-keywords-csv.php',
    'WPSEO_Export_Keywords_Post_Presenter' => $baseDir . '/classes/export/export-keywords-post-presenter.php',
    'WPSEO_Export_Keywords_Post_Query' => $baseDir . '/classes/export/export-keywords-post-query.php',
    'WPSEO_Export_Keywords_Presenter' => $baseDir . '/classes/export/export-keywords-presenter-interface.php',
    'WPSEO_Export_Keywords_Query' => $baseDir . '/classes/export/export-keywords-query-interface.php',
    'WPSEO_Export_Keywords_Term_Presenter' => $baseDir . '/classes/export/export-keywords-term-presenter.php',
    'WPSEO_Export_Keywords_Term_Query' => $baseDir . '/classes/export/export-keywords-term-query.php',
    'WPSEO_Facebook_Profile' => $baseDir . '/classes/facebook-profile.php',
    'WPSEO_Metabox_Link_Suggestions' => $baseDir . '/classes/metabox-link-suggestions.php',
    'WPSEO_Multi_Keyword' => $baseDir . '/classes/multi-keyword.php',
    'WPSEO_Post_Watcher' => $baseDir . '/classes/post-watcher.php',
    'WPSEO_Premium' => $baseDir . '/premium.php',
    'WPSEO_Premium_Asset_JS_L10n' => $baseDir . '/classes/premium-asset-js-l10n.php',
    'WPSEO_Premium_Assets' => $baseDir . '/classes/premium-assets.php',
    'WPSEO_Premium_Expose_Shortlinks' => $baseDir . '/classes/premium-expose-shortlinks.php',
    'WPSEO_Premium_Free_Translations' => $baseDir . '/classes/premium-free-translations.php',
    'WPSEO_Premium_Import_Manager' => $baseDir . '/classes/premium-import-manager.php',
    'WPSEO_Premium_Javascript_Strings' => $baseDir . '/classes/premium-javascript-strings.php',
    'WPSEO_Premium_Keyword_Export_Manager' => $baseDir . '/classes/premium-keyword-export-manager.php',
    'WPSEO_Premium_Metabox' => $baseDir . '/classes/premium-metabox.php',
    'WPSEO_Premium_Option' => $baseDir . '/classes/premium-option.php',
    'WPSEO_Premium_Orphaned_Content_Support' => $baseDir . '/classes/premium-orphaned-content-support.php',
    'WPSEO_Premium_Orphaned_Content_Utils' => $baseDir . '/classes/premium-orphaned-content-utils.php',
    'WPSEO_Premium_Orphaned_Post_Filter' => $baseDir . '/classes/premium-orphaned-post-filter.php',
    'WPSEO_Premium_Orphaned_Post_Notifier' => $baseDir . '/classes/premium-orphaned-post-notifier.php',
    'WPSEO_Premium_Orphaned_Post_Query' => $baseDir . '/classes/premium-orphaned-post-query.php',
    'WPSEO_Premium_Prominent_Words_Language_Support' => $baseDir . '/classes/deprecated/premium-prominent-words-language-support.php',
    'WPSEO_Premium_Prominent_Words_Recalculation' => $baseDir . '/classes/premium-prominent-words-recalculation.php',
    'WPSEO_Premium_Prominent_Words_Recalculation_Endpoint' => $baseDir . '/classes/deprecated/premium-prominent-words-recalculation-endpoint.php',
    'WPSEO_Premium_Prominent_Words_Recalculation_Notifier' => $baseDir . '/classes/deprecated/premium-prominent-words-recalculation-notifier.php',
    'WPSEO_Premium_Prominent_Words_Recalculation_Service' => $baseDir . '/classes/deprecated/premium-prominent-words-recalculation-service.php',
    'WPSEO_Premium_Prominent_Words_Support' => $baseDir . '/classes/premium-prominent-words-support.php',
    'WPSEO_Premium_Prominent_Words_Unindexed_Post_Query' => $baseDir . '/classes/premium-prominent-words-unindexed-post-query.php',
    'WPSEO_Premium_Prominent_Words_Versioning' => $baseDir . '/classes/premium-prominent-words-versioning.php',
    'WPSEO_Premium_Redirect_EndPoint' => $baseDir . '/classes/premium-redirect-endpoint.php',
    'WPSEO_Premium_Redirect_Export_Manager' => $baseDir . '/classes/premium-redirect-export-manager.php',
    'WPSEO_Premium_Redirect_Option' => $baseDir . '/classes/premium-redirect-option.php',
    'WPSEO_Premium_Redirect_Service' => $baseDir . '/classes/premium-redirect-service.php',
    'WPSEO_Premium_Redirect_Undo_EndPoint' => $baseDir . '/classes/redirect-undo-endpoint.php',
    'WPSEO_Premium_Register_Capabilities' => $baseDir . '/classes/premium-register-capabilities.php',
    'WPSEO_Premium_Stale_Cornerstone_Content_Filter' => $baseDir . '/classes/premium-stale-cornerstone-content-filter.php',
    'WPSEO_Product_Premium' => $baseDir . '/classes/product-premium.php',
    'WPSEO_Redirect' => $baseDir . '/classes/redirect/redirect.php',
    'WPSEO_Redirect_Abstract_Loader' => $baseDir . '/classes/redirect/loaders/redirect-abstract-loader.php',
    'WPSEO_Redirect_Abstract_Validation' => $baseDir . '/classes/redirect/validation/redirect-abstract-validation.php',
    'WPSEO_Redirect_Accessible_Validation' => $baseDir . '/classes/redirect/validation/redirect-accessible-validation.php',
    'WPSEO_Redirect_Ajax' => $baseDir . '/classes/redirect/redirect-ajax.php',
    'WPSEO_Redirect_Apache_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-apache-exporter.php',
    'WPSEO_Redirect_CSV_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-csv-exporter.php',
    'WPSEO_Redirect_CSV_Loader' => $baseDir . '/classes/redirect/loaders/redirect-csv-loader.php',
    'WPSEO_Redirect_Endpoint_Validation' => $baseDir . '/classes/redirect/validation/redirect-endpoint-validation.php',
    'WPSEO_Redirect_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-exporter-interface.php',
    'WPSEO_Redirect_File_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-file-exporter.php',
    'WPSEO_Redirect_File_Util' => $baseDir . '/classes/redirect/redirect-file-util.php',
    'WPSEO_Redirect_Form_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-form-presenter.php',
    'WPSEO_Redirect_Formats' => $baseDir . '/classes/redirect/redirect-formats.php',
    'WPSEO_Redirect_Formatter' => $baseDir . '/classes/redirect/redirect-formatter.php',
    'WPSEO_Redirect_HTAccess_Loader' => $baseDir . '/classes/redirect/loaders/redirect-htaccess-loader.php',
    'WPSEO_Redirect_Handler' => $baseDir . '/src/deprecated/redirect-handler.php',
    'WPSEO_Redirect_Htaccess_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-htaccess-exporter.php',
    'WPSEO_Redirect_Htaccess_Util' => $baseDir . '/classes/redirect/redirect-htaccess-util.php',
    'WPSEO_Redirect_Import_Exception' => $baseDir . '/classes/redirect/redirect-import-exception.php',
    'WPSEO_Redirect_Importer' => $baseDir . '/classes/redirect/redirect-importer.php',
    'WPSEO_Redirect_Loader' => $baseDir . '/classes/redirect/loaders/redirect-loader-interface.php',
    'WPSEO_Redirect_Manager' => $baseDir . '/classes/redirect/redirect-manager.php',
    'WPSEO_Redirect_Nginx_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-nginx-exporter.php',
    'WPSEO_Redirect_Option' => $baseDir . '/classes/redirect/redirect-option.php',
    'WPSEO_Redirect_Option_Exporter' => $baseDir . '/classes/redirect/exporters/redirect-option-exporter.php',
    'WPSEO_Redirect_Page' => $baseDir . '/classes/redirect/redirect-page.php',
    'WPSEO_Redirect_Page_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-page-presenter.php',
    'WPSEO_Redirect_Presence_Validation' => $baseDir . '/classes/redirect/validation/redirect-presence-validation.php',
    'WPSEO_Redirect_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-presenter-interface.php',
    'WPSEO_Redirect_Quick_Edit_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-quick-edit-presenter.php',
    'WPSEO_Redirect_Redirection_Loader' => $baseDir . '/classes/redirect/loaders/redirect-redirection-loader.php',
    'WPSEO_Redirect_Relative_Origin_Validation' => $baseDir . '/classes/redirect/validation/redirect-relative-origin-validation.php',
    'WPSEO_Redirect_Safe_Redirect_Loader' => $baseDir . '/classes/redirect/loaders/redirect-safe-redirect-loader.php',
    'WPSEO_Redirect_Self_Redirect_Validation' => $baseDir . '/classes/redirect/validation/redirect-self-redirect-validation.php',
    'WPSEO_Redirect_Settings_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-settings-presenter.php',
    'WPSEO_Redirect_Simple_301_Redirect_Loader' => $baseDir . '/classes/redirect/loaders/redirect-simple-301-redirect-loader.php',
    'WPSEO_Redirect_Sitemap_Filter' => $baseDir . '/classes/redirect/redirect-sitemap-filter.php',
    'WPSEO_Redirect_Subdirectory_Validation' => $baseDir . '/classes/redirect/validation/redirect-subdirectory-validation.php',
    'WPSEO_Redirect_Tab_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-tab-presenter.php',
    'WPSEO_Redirect_Table' => $baseDir . '/classes/redirect/redirect-table.php',
    'WPSEO_Redirect_Table_Presenter' => $baseDir . '/classes/redirect/presenters/redirect-table-presenter.php',
    'WPSEO_Redirect_Types' => $baseDir . '/classes/redirect/redirect-types.php',
    'WPSEO_Redirect_Uniqueness_Validation' => $baseDir . '/classes/redirect/validation/redirect-uniqueness-validation.php',
    'WPSEO_Redirect_Upgrade' => $baseDir . '/classes/redirect/redirect-upgrade.php',
    'WPSEO_Redirect_Url_Formatter' => $baseDir . '/classes/redirect/redirect-url-formatter.php',
    'WPSEO_Redirect_Util' => $baseDir . '/classes/redirect/redirect-util.php',
    'WPSEO_Redirect_Validation' => $baseDir . '/classes/redirect/validation/redirect-validation-interface.php',
    'WPSEO_Redirect_Validator' => $baseDir . '/classes/redirect/redirect-validator.php',
    'WPSEO_Social_Previews' => $baseDir . '/classes/social-previews.php',
    'WPSEO_Term_Watcher' => $baseDir . '/classes/term-watcher.php',
    'WPSEO_Upgrade_Manager' => $baseDir . '/classes/upgrade-manager.php',
    'WPSEO_Validation_Error' => $baseDir . '/classes/validation-error.php',
    'WPSEO_Validation_Result' => $baseDir . '/classes/validation-result.php',
    'WPSEO_Validation_Warning' => $baseDir . '/classes/validation-warning.php',
    'WPSEO_Watcher' => $baseDir . '/classes/watcher.php',
    'Yoast\\WP\\SEO\\Actions\\Link_Suggestions_Action' => $baseDir . '/src/deprecated/actions/renamed-classes.php',
    'Yoast\\WP\\SEO\\Actions\\Prominent_Words\\Complete_Action' => $baseDir . '/src/deprecated/actions/prominent-words/renamed-classes.php',
    'Yoast\\WP\\SEO\\Actions\\Prominent_Words\\Content_Action' => $baseDir . '/src/deprecated/actions/prominent-words/renamed-classes.php',
    'Yoast\\WP\\SEO\\Actions\\Prominent_Words\\Save_Action' => $baseDir . '/src/deprecated/actions/prominent-words/renamed-classes.php',
    'Yoast\\WP\\SEO\\Actions\\Zapier_Action' => $baseDir . '/src/deprecated/actions/renamed-classes.php',
    'Yoast\\WP\\SEO\\Conditionals\\Zapier_Enabled_Conditional' => $baseDir . '/src/deprecated/conditionals/renamed-classes.php',
    'Yoast\\WP\\SEO\\Config\\Migrations\\WpYoastPremiumImprovedInternalLinking' => $baseDir . '/src/config/migrations/20190715101200_WpYoastPremiumImprovedInternalLinking.php',
    'Yoast\\WP\\SEO\\Database\\Migration_Runner_Premium' => $baseDir . '/src/deprecated/database/renamed-classes.php',
    'Yoast\\WP\\SEO\\Helpers\\Prominent_Words_Helper' => $baseDir . '/src/deprecated/helpers/renamed-classes.php',
    'Yoast\\WP\\SEO\\Helpers\\Zapier_Helper' => $baseDir . '/src/deprecated/helpers/renamed-classes.php',
    'Yoast\\WP\\SEO\\Initializers\\Redirect_Handler' => $baseDir . '/src/deprecated/initializers/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Admin\\Prominent_Words\\Indexation_Integration' => $baseDir . '/src/deprecated/integrations/admin/prominent-words/indexation-integration.php',
    'Yoast\\WP\\SEO\\Integrations\\Admin\\Prominent_Words\\Indexing_Integration' => $baseDir . '/src/deprecated/integrations/admin/prominent-words/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Admin\\Prominent_Words\\Metabox_Integration' => $baseDir . '/src/deprecated/integrations/admin/prominent-words/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Admin\\Prominent_Words\\Notification_Event_Integration' => $baseDir . '/src/deprecated/integrations/admin/prominent-words/notification-event-integration.php',
    'Yoast\\WP\\SEO\\Integrations\\Admin\\Prominent_Words_Notification' => $baseDir . '/src/deprecated/integrations/admin/prominent-words-notification.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Block_Patterns' => $baseDir . '/src/integrations/blocks/block-patterns.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Estimated_Reading_Time_Block' => $baseDir . '/src/deprecated/integrations/blocks/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Job_Posting_Block' => $baseDir . '/src/integrations/blocks/job-posting-block.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Related_Links_Block' => $baseDir . '/src/deprecated/integrations/blocks/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Schema_Blocks' => $baseDir . '/src/deprecated/integrations/blocks/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Siblings_Block' => $baseDir . '/classes/blocks/siblings-block.php',
    'Yoast\\WP\\SEO\\Integrations\\Blocks\\Subpages_Block' => $baseDir . '/classes/blocks/subpages-block.php',
    'Yoast\\WP\\SEO\\Integrations\\Third_Party\\Elementor_Premium' => $baseDir . '/src/deprecated/integrations/third-party/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Third_Party\\TranslationsPress' => $baseDir . '/src/integrations/third-party/translationspress.php',
    'Yoast\\WP\\SEO\\Integrations\\Third_Party\\Zapier' => $baseDir . '/src/deprecated/integrations/third-party/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Third_Party\\Zapier_Classic_Editor' => $baseDir . '/src/deprecated/integrations/third-party/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Third_Party\\Zapier_Trigger' => $baseDir . '/src/deprecated/integrations/third-party/renamed-classes.php',
    'Yoast\\WP\\SEO\\Integrations\\Watchers\\Premium_Option_Wpseo_Watcher' => $baseDir . '/src/integrations/watchers/premium-option-wpseo-watcher.php',
    'Yoast\\WP\\SEO\\Integrations\\Watchers\\Zapier_APIKey_Reset_Watcher' => $baseDir . '/src/integrations/watchers/zapier-apikey-reset-watcher.php',
    'Yoast\\WP\\SEO\\Models\\Prominent_Words' => $baseDir . '/src/models/prominent-words.php',
    'Yoast\\WP\\SEO\\Premium\\Actions\\Link_Suggestions_Action' => $baseDir . '/src/actions/link-suggestions-action.php',
    'Yoast\\WP\\SEO\\Premium\\Actions\\Prominent_Words\\Complete_Action' => $baseDir . '/src/actions/prominent-words/complete-action.php',
    'Yoast\\WP\\SEO\\Premium\\Actions\\Prominent_Words\\Content_Action' => $baseDir . '/src/actions/prominent-words/content-action.php',
    'Yoast\\WP\\SEO\\Premium\\Actions\\Prominent_Words\\Save_Action' => $baseDir . '/src/actions/prominent-words/save-action.php',
    'Yoast\\WP\\SEO\\Premium\\Actions\\Zapier_Action' => $baseDir . '/src/actions/zapier-action.php',
    'Yoast\\WP\\SEO\\Premium\\Addon_Installer' => $baseDir . '/src/addon-installer.php',
    'Yoast\\WP\\SEO\\Premium\\Conditionals\\Zapier_Enabled_Conditional' => $baseDir . '/src/conditionals/zapier-enabled-conditional.php',
    'Yoast\\WP\\SEO\\Premium\\Config\\Badge_Group_Names' => $baseDir . '/src/config/badge-group-names.php',
    'Yoast\\WP\\SEO\\Premium\\Database\\Migration_Runner_Premium' => $baseDir . '/src/database/migration-runner-premium.php',
    'Yoast\\WP\\SEO\\Premium\\Generated\\Cached_Container' => $baseDir . '/src/generated/container.php',
    'Yoast\\WP\\SEO\\Premium\\Helpers\\Prominent_Words_Helper' => $baseDir . '/src/helpers/prominent-words-helper.php',
    'Yoast\\WP\\SEO\\Premium\\Helpers\\Zapier_Helper' => $baseDir . '/src/helpers/zapier-helper.php',
    'Yoast\\WP\\SEO\\Premium\\Initializers\\Plugin' => $baseDir . '/src/initializers/plugin.php',
    'Yoast\\WP\\SEO\\Premium\\Initializers\\Redirect_Handler' => $baseDir . '/src/initializers/redirect-handler.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Abstract_OpenGraph_Integration' => $baseDir . '/src/integrations/abstract-opengraph-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\Plugin_Links_Integration' => $baseDir . '/src/integrations/admin/plugin-links-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\Prominent_Words\\Indexing_Integration' => $baseDir . '/src/integrations/admin/prominent-words/indexing-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\Prominent_Words\\Metabox_Integration' => $baseDir . '/src/integrations/admin/prominent-words/metabox-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\Thank_You_Page_Integration' => $baseDir . '/src/integrations/admin/thank-you-page-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\User_Profile_Integration' => $baseDir . '/src/integrations/admin/user-profile-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Admin\\Workouts_Integration' => $baseDir . '/src/integrations/admin/workouts-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Blocks\\Estimated_Reading_Time_Block' => $baseDir . '/src/integrations/blocks/estimated-reading-time-block.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Blocks\\Related_Links_Block' => $baseDir . '/src/integrations/blocks/related-links-block.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Blocks\\Schema_Blocks' => $baseDir . '/src/integrations/blocks/schema-blocks.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\OpenGraph_Author_Archive' => $baseDir . '/src/integrations/opengraph-author-archive.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\OpenGraph_Date_Archive' => $baseDir . '/src/integrations/opengraph-date-archive.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\OpenGraph_PostType_Archive' => $baseDir . '/src/integrations/opengraph-posttype-archive.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\OpenGraph_Post_Type' => $baseDir . '/src/integrations/opengraph-post-type.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\OpenGraph_Term_Archive' => $baseDir . '/src/integrations/opengraph-term-archive.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Third_Party\\Elementor_Premium' => $baseDir . '/src/integrations/third-party/elementor-premium.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Third_Party\\Zapier' => $baseDir . '/src/integrations/third-party/zapier.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Third_Party\\Zapier_Classic_Editor' => $baseDir . '/src/integrations/third-party/zapier-classic-editor.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Third_Party\\Zapier_Trigger' => $baseDir . '/src/integrations/third-party/zapier-trigger.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\Upgrade_Integration' => $baseDir . '/src/integrations/upgrade-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Integrations\\User_Profile_Integration' => $baseDir . '/src/integrations/user-profile-integration.php',
    'Yoast\\WP\\SEO\\Premium\\Main' => $baseDir . '/src/main.php',
    'Yoast\\WP\\SEO\\Premium\\Routes\\Workouts_Route' => $baseDir . '/src/routes/workouts-route.php',
    'Yoast\\WP\\SEO\\Premium\\Surfaces\\Helpers_Surface' => $baseDir . '/src/surfaces/helpers-surface.php',
    'Yoast\\WP\\SEO\\Premium\\WordPress\\Wrapper' => $baseDir . '/src/wordpress/wrapper.php',
    'Yoast\\WP\\SEO\\Presenters\\Admin\\Prominent_Words\\Indexation_List_Item_Presenter' => $baseDir . '/src/deprecated/presenters/indexation-list-item-presenter.php',
    'Yoast\\WP\\SEO\\Presenters\\Admin\\Prominent_Words\\Indexation_Modal_Presenter' => $baseDir . '/src/deprecated/presenters/indexation-modal-presenter.php',
    'Yoast\\WP\\SEO\\Presenters\\Prominent_Words_Notification' => $baseDir . '/src/deprecated/presenters/prominent-words-notification.php',
    'Yoast\\WP\\SEO\\Repositories\\Prominent_Words_Repository' => $baseDir . '/src/repositories/prominent-words-repository.php',
    'Yoast\\WP\\SEO\\Routes\\Link_Suggestions_Route' => $baseDir . '/src/routes/link-suggestions-route.php',
    'Yoast\\WP\\SEO\\Routes\\Prominent_Words_Route' => $baseDir . '/src/routes/prominent-words-route.php',
    'Yoast\\WP\\SEO\\Routes\\Zapier_Route' => $baseDir . '/src/routes/zapier-route.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Block_Pattern' => $baseDir . '/src/schema-templates/block-patterns/block-pattern.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Block_Pattern_Categories' => $baseDir . '/src/schema-templates/block-patterns/block-pattern-categories.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Block_Pattern_Keywords' => $baseDir . '/src/schema-templates/block-patterns/block-pattern-keywords.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Job_Posting_Base_Pattern' => $baseDir . '/src/schema-templates/block-patterns/job-posting-base-pattern.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Job_Posting_Default' => $baseDir . '/src/schema-templates/block-patterns/job-posting-default.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Job_Posting_Minimal' => $baseDir . '/src/schema-templates/block-patterns/job-posting-minimal.php',
    'Yoast\\WP\\SEO\\Schema_Templates\\Block_Patterns\\Job_Posting_Yoast_Com' => $baseDir . '/src/schema-templates/block-patterns/job-posting-yoast-com.php',
    'Yoast\\WP\\SEO\\WordPress\\Premium_Wrapper' => $baseDir . '/src/deprecated/wordpress/renamed-classes.php',
);
