<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'AIOSEO\\Plugin\\Addon\\ImageSeo\\Admin\\Admin' => $baseDir . '/app/Admin/Admin.php',
    'AIOSEO\\Plugin\\Addon\\ImageSeo\\ImageSeo' => $baseDir . '/app/ImageSeo.php',
    'AIOSEO\\Plugin\\Addon\\ImageSeo\\Image\\Image' => $baseDir . '/app/Image/Image.php',
    'AIOSEO\\Plugin\\Addon\\ImageSeo\\Utils\\Helpers' => $baseDir . '/app/Utils/Helpers.php',
    'AIOSEO\\Plugin\\Addon\\ImageSeo\\Utils\\Tags' => $baseDir . '/app/Utils/Tags.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
);
